@@ -1,5 +1,3 @@
-context("day")
-
 test_that("dtt_day.Date", {
   expect_identical(dtt_day(as.Date("2001-01-01")[-1]), integer(0))
   expect_identical(dtt_day(as.Date("2001-01-01")), 1L)
@@ -50,6 +48,12 @@ test_that("dtt_day<-.Date", {
   expect_identical(dtt_day(x2), c(10L, NA))
 })
 
+test_that("dtt_day<-.Date preserves names", {
+  x <- setNames(as.Date("2001-01-01"), "a name")
+  dtt_day(x) <- 2L
+  expect_identical(names(x), "a name")
+})
+
 test_that("dtt_day<-.POSIXct", {
   x0 <- Sys.time()[-1]
   dtt_day(x0) <- 22L
@@ -90,3 +94,9 @@ test_that("dtt_day<-.POSIXct", {
   dtt_day(x2) <- c(10L, 10L)
   expect_identical(dtt_day(x2), c(10L, NA))
 })
+
+test_that("dtt_day<-.POSIXct preserves names", {
+  x <- setNames(as.POSIXct("1990-01-17 23:40:51", tz = "PST8PDT"), "a name")
+  dtt_day(x) <- 2L
+  expect_identical(names(x), "a name")
+})
