@@ -1,5 +1,3 @@
-context("year")
-
 test_that("dtt_year.Date", {
   expect_identical(dtt_year(as.Date("2001-01-01")[-1]), integer(0))
   expect_identical(dtt_year(as.Date("2001-01-01")), 2001L)
@@ -50,6 +48,12 @@ test_that("dtt_year<-.Date", {
   expect_identical(dtt_year(x2), c(10L, NA))
 })
 
+test_that("dtt_year<-.Date preserves names", {
+  x <- setNames(as.Date("2001-01-01"), "a name")
+  dtt_year(x) <- 2000L
+  expect_identical(names(x), "a name")
+})
+
 test_that("dtt_year<-.POSIXct", {
   x0 <- Sys.time()[-1]
   dtt_year(x0) <- 11L
@@ -90,3 +94,9 @@ test_that("dtt_year<-.POSIXct", {
   dtt_year(x2) <- c(10L, 10L)
   expect_identical(dtt_year(x2), c(10L, NA))
 })
+
+test_that("dtt_year<-.POSIXct preserves names", {
+  x <- setNames(as.POSIXct("1990-01-17 23:40:51", tz = "PST8PDT"), "a name")
+  dtt_year(x) <- 2000L
+  expect_identical(names(x), "a name")
+})
